@@ -30,15 +30,15 @@
  */
 
 /*
- * $Id: charconv.c,v 1.17 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: charconv.c,v 1.22 2006/07/03 16:36:08 skunk Exp $
  */
 
-#include "charconv.h"
-
-#ifndef CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "charconv.h"
+
 #ifdef HAVE_ICONV
 #include <iconv.h>
 #endif
@@ -49,6 +49,9 @@
 
 #include "mmapstring.h"
 
+int (*extended_charconv)(const char * tocode, const char * fromcode, const char * str, size_t length,
+    char * result, size_t* result_len) = NULL;
+
 #ifdef HAVE_ICONV
 static size_t mail_iconv (iconv_t cd, const char **inbuf, size_t *inbytesleft,
     char **outbuf, size_t *outbytesleft,
@@ -124,17 +127,42 @@ int charconv(const char * tocode, const char * fromcode,
     const char * str, size_t length,
     char ** result)
 {
+#ifdef HAVE_ICONV
+	iconv_t conv;
+	size_t r;
+	char * pout;
+	size_t out_size;
+	size_t old_out_size;
+	size_t count;
+#endif
+	char * out;
+	int res;
+
+	if (extended_charconv != NULL) {
+		size_t		result_length;
+		result_length = length * 6;
+		*result = malloc( length * 6 + 1);
+		if (*result == NULL) {
+			res = MAIL_CHARCONV_ERROR_MEMORY;
+		} else {
+			res = (*extended_charconv)( tocode, fromcode, str, length, *result, &result_length);
+			if (res != MAIL_CHARCONV_NO_ERROR) {
+				free( *result);
+			} else {
+				out = realloc( *result, result_length + 1);
+				if (out != NULL) *result = out;
+				/* also a cstring, just in case */
+				(*result)[result_length] = '\0';
+			}
+		}
+		if (res != MAIL_CHARCONV_ERROR_UNKNOWN_CHARSET)
+			return res;
+		/* else, let's try with iconv, if available */
+	}
+
 #ifndef HAVE_ICONV
   return MAIL_CHARCONV_ERROR_UNKNOWN_CHARSET;
 #else
-  iconv_t conv;
-  size_t r;
-  char * out;
-  char * pout;
-  size_t out_size;
-  size_t old_out_size;
-  size_t count;
-  int res;
 
   conv = iconv_open(tocode, fromcode);
   if (conv == (iconv_t) -1) {
@@ -142,7 +170,7 @@ int charconv(const char * tocode, const char * fromcode,
     goto err;
   }
 
-  out_size = 4 * length;
+  out_size = 6 * length; /* UTF-8 can be encoded up to 6 bytes */
 
   out = malloc(out_size + 1);
   if (out == NULL) {
@@ -179,26 +207,57 @@ int charconv(const char * tocode, const char * fromcode,
  err:
   return res;
 #endif
-};
+}
 
 LIBETPAN_EXPORT
 int charconv_buffer(const char * tocode, const char * fromcode,
 		    const char * str, size_t length,
 		    char ** result, size_t * result_len)
 {
+#ifdef HAVE_ICONV
+	iconv_t conv;
+	size_t iconv_r;
+	int r;
+	char * out;
+	char * pout;
+	size_t out_size;
+	size_t old_out_size;
+	size_t count;
+#endif
+	int res;
+	MMAPString * mmapstr;
+
+	if (extended_charconv != NULL) {
+		size_t		result_length;
+		result_length = length * 6;
+		mmapstr = mmap_string_sized_new( result_length + 1);
+		*result_len = 0;
+		if (mmapstr == NULL) {
+			res = MAIL_CHARCONV_ERROR_MEMORY;
+		} else {
+			res = (*extended_charconv)( tocode, fromcode, str, length, mmapstr->str, &result_length);
+			if (res != MAIL_CHARCONV_ERROR_UNKNOWN_CHARSET) {
+				if (res == MAIL_CHARCONV_NO_ERROR) {
+					*result = mmapstr->str;
+					res = mmap_string_ref(mmapstr);
+					if (res < 0) {
+						res = MAIL_CHARCONV_ERROR_MEMORY;
+						mmap_string_free(mmapstr);
+					} else {
+						mmap_string_set_size( mmapstr, result_length);	/* can't fail */
+						*result_len = result_length;
+					}
+				}
+				free( *result);
+			}
+			return res;
+		}
+		/* else, let's try with iconv, if available */
+	}
+
 #ifndef HAVE_ICONV
   return MAIL_CHARCONV_ERROR_UNKNOWN_CHARSET;
 #else
-  iconv_t conv;
-  size_t iconv_r;
-  int r;
-  char * out;
-  char * pout;
-  size_t out_size;
-  size_t old_out_size;
-  size_t count;
-  MMAPString * mmapstr;
-  int res;
 
   conv = iconv_open(tocode, fromcode);
   if (conv == (iconv_t) -1) {
@@ -206,7 +265,7 @@ int charconv_buffer(const char * tocode, const char * fromcode,
     goto err;
   }
 
-  out_size = 4 * length;
+  out_size = 6 * length; /* UTF-8 can be encoded up to 6 bytes */
 
   mmapstr = mmap_string_sized_new(out_size + 1);
   if (mmapstr == NULL) {
@@ -248,7 +307,7 @@ int charconv_buffer(const char * tocode, const char * fromcode,
  err:
   return res;
 #endif
-};
+}
 
 LIBETPAN_EXPORT
 void charconv_buffer_free(char * str)
