@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver.h,v 1.33 2005/08/15 11:08:40 hoa Exp $
+ * $Id: maildriver.h,v 1.34 2006/06/07 15:10:01 smarinier Exp $
  */
 
 #ifndef MAILDRIVER_H
@@ -102,7 +102,7 @@ int mailsession_connect_stream(mailsession * session, mailstream * s);
 */
 
 LIBETPAN_EXPORT
-int mailsession_connect_path(mailsession * session, char * path);
+int mailsession_connect_path(mailsession * session, const char * path);
 
 /*
   NOTE: works only on stream drivers
@@ -131,7 +131,7 @@ int mailsession_starttls(mailsession * session);
 
 LIBETPAN_EXPORT
 int mailsession_login(mailsession * session,
-		      char * userid, char * password);
+		      const char * userid, const char * password);
 
 /*
   NOTE: this function doesn't often work on filsystem drivers
@@ -173,8 +173,8 @@ int mailsession_noop(mailsession * session);
 */
 
 LIBETPAN_EXPORT
-int mailsession_build_folder_name(mailsession * session, char * mb,
-				  char * name, char ** result);
+int mailsession_build_folder_name(mailsession * session, const char * mb,
+				  const char * name, char ** result);
 
 /*
   NOTE: driver's specific should be used
@@ -190,7 +190,7 @@ int mailsession_build_folder_name(mailsession * session, char * mb,
 */
 
 LIBETPAN_EXPORT
-int mailsession_create_folder(mailsession * session, char * mb);
+int mailsession_create_folder(mailsession * session, const char * mb);
 
 
 /*
@@ -207,7 +207,7 @@ int mailsession_create_folder(mailsession * session, char * mb);
 */
 
 LIBETPAN_EXPORT
-int mailsession_delete_folder(mailsession * session, char * mb);
+int mailsession_delete_folder(mailsession * session, const char * mb);
 
 
 /*
@@ -224,7 +224,7 @@ int mailsession_delete_folder(mailsession * session, char * mb);
 
 LIBETPAN_EXPORT
 int mailsession_rename_folder(mailsession * session,
-			      char * mb, char * new_name);
+			      const char * mb, const char * new_name);
 
 /*
   mailsession_check_folder makes a checkpoint of the session
@@ -249,7 +249,7 @@ int mailsession_check_folder(mailsession * session);
 */
 
 LIBETPAN_EXPORT
-int mailsession_examine_folder(mailsession * session, char * mb);
+int mailsession_examine_folder(mailsession * session, const char * mb);
 
 
 /*
@@ -260,7 +260,7 @@ int mailsession_examine_folder(mailsession * session, char * mb);
 */
 
 LIBETPAN_EXPORT
-int mailsession_select_folder(mailsession * session, char * mb);
+int mailsession_select_folder(mailsession * session, const char * mb);
 
 
 /*
@@ -292,7 +292,7 @@ int mailsession_expunge_folder(mailsession * session);
 */
 
 LIBETPAN_EXPORT
-int mailsession_status_folder(mailsession * session, char * mb,
+int mailsession_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
 
@@ -309,7 +309,7 @@ int mailsession_status_folder(mailsession * session, char * mb,
 */
 
 LIBETPAN_EXPORT
-int mailsession_messages_number(mailsession * session, char * mb,
+int mailsession_messages_number(mailsession * session, const char * mb,
 				uint32_t * result);
 
 /*
@@ -325,7 +325,7 @@ int mailsession_messages_number(mailsession * session, char * mb,
 
 LIBETPAN_EXPORT
 int mailsession_recent_number(mailsession * session,
-			      char * mb, uint32_t * result);
+			      const char * mb, uint32_t * result);
 
 /*
   mailsession_unseen_number queries the number of unseen messages in the folder
@@ -339,7 +339,7 @@ int mailsession_recent_number(mailsession * session,
 */
 
 LIBETPAN_EXPORT
-int mailsession_unseen_number(mailsession * session, char * mb,
+int mailsession_unseen_number(mailsession * session, const char * mb,
 			      uint32_t * result);
 
 /*
@@ -358,7 +358,7 @@ int mailsession_unseen_number(mailsession * session, char * mb,
 */
 
 LIBETPAN_EXPORT
-int mailsession_list_folders(mailsession * session, char * mb,
+int mailsession_list_folders(mailsession * session, const char * mb,
 			     struct mail_list ** result);
 
 /*
@@ -377,7 +377,7 @@ int mailsession_list_folders(mailsession * session, char * mb,
 */
 
 LIBETPAN_EXPORT
-int mailsession_lsub_folders(mailsession * session, char * mb,
+int mailsession_lsub_folders(mailsession * session, const char * mb,
 			     struct mail_list ** result);
 
 /*
@@ -393,7 +393,7 @@ int mailsession_lsub_folders(mailsession * session, char * mb,
 */
 
 LIBETPAN_EXPORT
-int mailsession_subscribe_folder(mailsession * session, char * mb);
+int mailsession_subscribe_folder(mailsession * session, const char * mb);
 
 /*
   NOTE: driver's specific should be used
@@ -408,7 +408,7 @@ int mailsession_subscribe_folder(mailsession * session, char * mb);
 */
 
 LIBETPAN_EXPORT
-int mailsession_unsubscribe_folder(mailsession * session, char * mb);
+int mailsession_unsubscribe_folder(mailsession * session, const char * mb);
 
 /*
   mailsession_append_message adds a RFC 2822 message to the current
@@ -424,11 +424,11 @@ int mailsession_unsubscribe_folder(mailsession * session, char * mb);
 
 LIBETPAN_EXPORT
 int mailsession_append_message(mailsession * session,
-			       char * message, size_t size);
+			       const char * message, size_t size);
 
 LIBETPAN_EXPORT
 int mailsession_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 
 /*
   NOTE: some drivers does not implement this
@@ -446,7 +446,7 @@ int mailsession_append_message_flags(mailsession * session,
 
 LIBETPAN_EXPORT
 int mailsession_copy_message(mailsession * session,
-			     uint32_t num, char * mb);
+			     uint32_t num, const char * mb);
 
 /*
   NOTE: some drivers does not implement this
@@ -464,7 +464,7 @@ int mailsession_copy_message(mailsession * session,
 
 LIBETPAN_EXPORT
 int mailsession_move_message(mailsession * session,
-			     uint32_t num, char * mb);
+			     uint32_t num, const char * mb);
 
 /*
   mailsession_get_messages_list returns the list of message numbers
@@ -532,7 +532,7 @@ int mailsession_remove_message(mailsession * session, uint32_t num);
 
 #if 0
 LIBETPAN_EXPORT
-int mailsession_search_messages(mailsession * session, char * charset,
+int mailsession_search_messages(mailsession * session, const char * charset,
 				struct mail_search_key * key,
 				struct mail_search_result ** result);
 #endif
