@@ -242,10 +242,11 @@ static int setup_unknown_encoding(const char * charset, XML_Encoding * info)
   char buf[4];
   unsigned int i;
   int r;
-  
+
   cd = iconv_open("UTF-32BE", charset);
-  if (cd == (iconv_t) (-1))
+  if (cd == (iconv_t) (-1)) {
     return -1;
+  }
   
   flag = 0;
   for (i = 0; i < 256; i++) {
@@ -271,6 +272,7 @@ static int setup_unknown_encoding(const char * charset, XML_Encoding * info)
         if (r == LEP_ICONV_OK) {
           flag = 1;
           info->map[i] = -2;
+          break;
         }
         else if (r != LEP_ICONV_INVAL) {
           /* do nothing */
@@ -283,7 +285,9 @@ static int setup_unknown_encoding(const char * charset, XML_Encoding * info)
             buf[2] = k;
             r = iconv_utf32_char(cd, buf, 3, &value);
             if (r == LEP_ICONV_OK) {
+              flag = 1;
               info->map[i] = -3;
+              break;
             }
           }
         }
@@ -299,6 +303,7 @@ static int setup_unknown_encoding(const char * charset, XML_Encoding * info)
 struct unknown_encoding_data {
   char * charset;
   iconv_t cd;
+  char map[256];
 };
 
 static int unknown_encoding_convert(void * data, const char * s)
@@ -309,16 +314,16 @@ static int unknown_encoding_convert(void * data, const char * s)
   uint32_t value;
   
   enc_data = data;
-  insize = 4;
   
   if (s == NULL)
     goto err;
   
+  insize = -enc_data->map[(unsigned char) s[0]];
   r = iconv_utf32_char(enc_data->cd, s, insize, &value);
   if (r != LEP_ICONV_OK)
     return -1;
   
-  return 0;
+  return value;
   
  err:
   return -1;
@@ -340,7 +345,8 @@ static int unknown_encoding_handler(void * encdata, const XML_Char * name,
   iconv_t cd;
   struct unknown_encoding_data * data;
   int result;
-  
+  unsigned int i;
+
   result = setup_unknown_encoding(name, info);
   if (result == 0) {
     info->data = NULL;
@@ -363,6 +369,9 @@ static int unknown_encoding_handler(void * encdata, const XML_Char * name,
     goto free_data;
   
   data->cd = cd;
+  for(i = 0 ; i < 256 ; i ++) {
+    data->map[i] = info->map[i];
+  }
   info->data = data;
   info->convert = unknown_encoding_convert;
   info->release = unknown_encoding_data_free;
